package com.mortals.xhx.busiz.web;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.common.Rest;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.xhx.busiz.rsp.ApiResp;
import com.mortals.xhx.common.code.ApiRespCodeEnum;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.pdu.user.UserPdu;
import com.mortals.xhx.common.utils.BeanUtil;
import com.mortals.xhx.feign.req.BaseUserQuery;
import com.mortals.xhx.feign.req.BaseUserReq;
import com.mortals.xhx.feign.rsp.UserRsp;
import com.mortals.xhx.module.user.model.UserEntity;
import com.mortals.xhx.module.user.model.UserQuery;
import com.mortals.xhx.module.user.service.UserService;
import lombok.extern.apachecommons.CommonsLog;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import static com.mortals.framework.ap.SysConstains.PAGEINFO_KEY;

/**
 * 用户对外服务接口
 *
 * @author: zxfei
 * @date: 2022/5/30 11:04
 */
@RestController
@CommonsLog
@RequestMapping("/api/user")
public class UserApiController {
    @Autowired
    private UserService userService;

    /**
     * 用户列表
     * @param userPdu
     * @return
     */
    @PostMapping("/findAllUser")
    public String findAllUser(@RequestBody UserEntity userPdu) {
        Rest<Object> rest = Rest.ok("获取列表成功");
        PageInfo page = new PageInfo();
        page.setPrePageResult(-1);
        try {
            if (!ObjectUtils.isEmpty(userPdu.getPage())) {
                page.setPrePageResult(userPdu.getSize() );
                page.setCurrPage(userPdu.getPage());
            }
            Result<UserEntity> result = userService.find(userPdu, page, null);
            Map<String, Object> model = new HashMap<>();
            model.put("data", result.getList());
            model.put(PAGEINFO_KEY, result.getPageInfo());
            rest.setData(model);

        } catch (Exception e) {
            log.error("获取用户列表异常", e);
            rest.setCode(YesNoEnum.NO.getValue());
            rest.setMsg(e.getMessage());
        }
        log.info("响应【用户列表】【响应体】-->  " + JSONObject.toJSONString(rest));
        return JSON.toJSONString(rest);
    }

}
